@@ -16,8 +16,8 @@ def create_summary(self, *, label: Union[str, None]=None):
 
     data = {
         'type': 'Summary',
-        'recordingDescription': self.recording_description,
-        'sortingDescription': self.sorting_description,
+        'recordingDescription': '',
+        'sortingDescription': '',
         'recordingObject': self.recording_object,
         'sortingObject': self.sorting_object,
         'unitIds': self.unit_ids,
@@ -31,5 +31,5 @@ def create_summary(self, *, label: Union[str, None]=None):
     return Figure(data=data, label=label)
 
 def estimate_noise_level(traces: np.ndarray):
-    est_noise_level = np.median(np.abs(traces.ravel())) / 0.6745  # median absolute deviation (MAD) estimate of stdev
+    est_noise_level = np.median(np.abs(traces - np.mean(traces, axis=0))) / 0.6745  # median absolute deviation (MAD) estimate of stdev
     return est_noise_level
\ No newline at end of file
