@@ -35,6 +35,25 @@ def _serialize(x):
             return x
     raise Exception(f'Item is not json safe: {type(x)}')
 
+def _deserialize(x):
+    if type(x) == dict:
+        if x.get('_type', None) == 'ndarray':
+            shape = x['shape']
+            dtype = x['dtype']
+            data_b64 = x['data_b64']
+            data = base64.b64decode(data_b64)
+            x = np.reshape(np.frombuffer(data, dtype=dtype), shape)
+            return x
+        else:
+            ret = dict()
+            for key, val in x.items():
+                ret[key] = _deserialize(val)
+            return ret
+    elif (type(x) == list) or (type(x) == tuple):
+        return [_deserialize(val) for val in x]
+    else:
+        return x
+
 def _is_jsonable(x) -> bool:
     import json
     try:
