@@ -9,6 +9,7 @@ from .workspace_sorting_curation_action import *
 from .latency_test import *
 from .python_package_version import *
 from .get_workspace_list import *
-from .get_figure_object import *
 from .get_experitime_timeseries_samples import *
-from .get_snippets_for_uri import *
\ No newline at end of file
+from .get_snippets_for_uri import *
+from .ssv_sorting_curation_action import *
+from .ssv_fetch_cross_correlogram import *
\ No newline at end of file
