@@ -2,8 +2,8 @@ import json
 from typing import Any, Dict, List, Tuple, Union
 import uuid
 import kachery_client as kc
-from figurl import Figure
-import spikeextractors as se
+
+from sortingview.experimental.SpikeSortingView.SpikeSortingView import SpikeSortingView
 from ..extractors import LabboxEphysRecordingExtractor, LabboxEphysSortingExtractor
 
 def parse_workspace_uri(workspace_uri: str):
@@ -121,6 +121,8 @@ class Workspace:
         main_subfeed = self._feed.load_subfeed('main')
         _set_unit_metrics_for_sorting(main_subfeed, x)
         self._unit_metrics_for_sortings[sorting_id] = metrics
+    def get_unit_metrics_for_sorting(self, sorting_id: str):
+        return self._unit_metrics_for_sortings.get(sorting_id, [])
     def delete_recording(self, recording_id: str):
         if recording_id not in self._recordings:
             raise Exception(f'Recording not found: {recording_id}')
@@ -137,21 +139,23 @@ class Workspace:
         main_subfeed = self._feed.load_subfeed('main')
         _set_user_permissions_for_workspace(main_subfeed, user_id, permissions)
         self._user_permissions[user_id] = permissions
+    def set_sorting_curation_authorized_users(self, *, sorting_id: str, user_ids):
+        sorting_curation_uri = self.get_curation_subfeed(sorting_id).uri
+        SpikeSortingView.set_sorting_curation_authorized_users(sorting_curation_uri, user_ids)
+    def get_sorting_curation_authorized_users(self, *, sorting_id: str):
+        sorting_curation_uri = self.get_curation_subfeed(sorting_id).uri
+        return SpikeSortingView.get_sorting_curation_authorized_users(sorting_curation_uri)
     def set_snippet_len(self, snippet_len: Tuple[int, int]):
         main_subfeed = self._feed.load_subfeed('main')
         _set_snippet_len_for_workspace(main_subfeed, snippet_len)
         self._snippet_len = snippet_len
     def figurl(self):
+        from figurl import Figure
         data = {
             'type': 'workspace',
             'workspaceUri': self.uri
         }
         return Figure(view_url='gs://figurl/sortingview-gui-1', data=data)
-    def figurl_old(self):
-        data = {
-            'workspaceUri': self.uri
-        }
-        return Figure(type='sortingview.workspace.1', data=data)
     @property
     def snippet_len(self):
         return self._snippet_len
@@ -177,9 +181,14 @@ class Workspace:
     def get_sorting_extractor(self, sorting_id):
         s = self.get_sorting(sorting_id)
         return LabboxEphysSortingExtractor(s['sortingObject'])
+    def get_curation_subfeed(self, sorting_id: str) -> kc.Subfeed:
+        return self._feed.load_subfeed(dict(name='sortingCuration', sortingId=sorting_id))
     def get_sorting_curation(self, sorting_id: str):
-        curation_subfeed = self._feed.load_subfeed(dict(name='sortingCuration', sortingId=sorting_id))
+        curation_subfeed = self.get_curation_subfeed(sorting_id)
         return _get_sorting_curation(curation_subfeed, sorting_id=sorting_id)
+    def get_sorting_curation_uri(self, sorting_id: str):
+        curation_subfeed = self.get_curation_subfeed(sorting_id)
+        return curation_subfeed.uri
     def get_curated_sorting_extractor(self, sorting_id):
         s = self.get_sorting(sorting_id)
         sc = self.get_sorting_curation(sorting_id)
@@ -190,6 +199,7 @@ class Workspace:
                 'merge_groups': sc.get('mergeGroups', [])
             }
         })
+    from ._experimental_spikesortingview import experimental_spikesortingview
 
 def create_workspace(*, label: Union[str, None]=None):
     feed = kc.create_feed()
